package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Apr 22, 2020
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Temperature struct{}
Temperature
Convert is function converting different temperature units
It can convert Celsius(c), Kelvin(k) and Fahrenheit(f)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.